## Description

<!-- A clear and concise description of what this PR does. -->

## Related issue

<!-- Link to the issue this PR addresses, e.g. "Closes #42" -->

## Type of change

- [ ] 🐛 Bug fix (non-breaking change that fixes an issue)
- [ ] ✨ New feature (non-breaking change that adds functionality)
- [ ] 💥 Breaking change (fix or feature that would cause existing functionality to change)
- [ ] 📝 Documentation update
- [ ] 🔧 Refactor / chore

## Checklist

- [ ] I have tested my changes locally (`uvx az-scout` or `uv run az-scout`)
- [ ] I have updated the documentation / README if needed
- [ ] My changes do not introduce new warnings or errors

## Screenshots

<!-- If applicable, add screenshots showing the change. -->
